"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
const nest_librarian_1 = require("@jchpro/nest-librarian");
const case_anything_1 = require("case-anything");
const config_1 = require("../config");
const collector_1 = require("../templates/collector");
const migration_1 = require("../templates/migration");
const datetime_1 = require("../utilities/datetime");
const path_1 = require("path");
const promises_1 = require("fs/promises");
const directories_1 = require("../utilities/directories");
async function generate(name, options) {
    // Get Nest project workspace
    const workspace = await nest_librarian_1.Project.locate(libName => libName === name);
    const nest = workspace.config;
    const migrate = (await workspace.getPackageJson()).mongoMigrate;
    // Check migrate config
    if (!migrate) {
        console.error(`Migrate configuration is not set up, please run 'setup' command first.`);
        process.exit(1);
    }
    // Get project config
    let projectName;
    let project;
    let nestProject;
    if (nest.projects) {
        // Monorepo
        if (!migrate.projects) {
            console.error(`There aren't any projects configured, please run 'setup' command first`);
            process.exit(1);
        }
        const useDefault = !options.project;
        if (useDefault && !migrate.default) {
            console.error(`Default project isn't defined in the configuration and project was not provided`);
            process.exit(1);
        }
        projectName = useDefault ? migrate.default : options.project;
        project = migrate.projects[projectName];
        nestProject = nest.projects[projectName];
    }
    else {
        // Non-monorepo
        if (!migrate.root) {
            console.error(`Project in non-monorepo workspace isn't configured, please run 'setup' command first`);
            process.exit(1);
        }
        project = migrate.root;
    }
    // Generate migration file
    const paths = (0, directories_1.resolveMigrateDirs)(workspace.rootDir, project, nestProject);
    const migrationContent = (0, migration_1.migrationTemplate)(config_1.LIB_NAME, name);
    const timestamp = (0, datetime_1.getTimestamp)();
    const migrationFilename = `${timestamp}_${(0, case_anything_1.snakeCase)(name)}.ts`;
    const migrationPath = (0, path_1.resolve)(paths.directory, migrationFilename);
    await (0, promises_1.writeFile)(migrationPath, migrationContent);
    console.log(`Migration created: ${migrationPath}`);
    // Regenerate collector file
    const collectorDir = (0, path_1.dirname)(paths.collector);
    const migrations = (await (0, nest_librarian_1.readDirFiles)(paths.directory, '.ts'))
        .map(filePath => {
        const fileNoExt = (0, path_1.basename)(filePath)
            .replace(/\.ts$/, '');
        const datePart = (/([\d-]+)_/.exec(fileNoExt)[1]);
        const namePart = fileNoExt.replace(datePart + '_', '');
        const relativePath = (0, path_1.relative)(collectorDir, (0, path_1.resolve)(paths.directory, fileNoExt))
            .split(path_1.sep)
            .join(path_1.posix.sep);
        const ts = datePart.replaceAll('-', '_');
        return {
            id: `${ts}_${namePart}`,
            token: `migration_${ts}`,
            importPath: `./${relativePath}`
        };
    });
    const collectorContent = (0, collector_1.collectorTemplate)(config_1.LIB_NAME, migrations);
    await ((0, promises_1.writeFile)(paths.collector, collectorContent));
    console.log(`Collector file updated`);
}
exports.generate = generate;
